NLSL: lbasix.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
lbasix.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | lbasix (ixname, bss, mts, lthb, maxb, new, ierr)

## Function/Subroutine Documentation

subroutine lbasix | ( | character*30 | ixname,
|  | integer, dimension(5,lthb) | bss,
|  | integer, dimension(mxmts) | mts,
|  | integer | lthb,
|  | integer | maxb,
|  | integer | new,
|  | integer | ierr
| ) |  |

Definition at line 39 of file lbasix.f90.

Here is the caller graph for this function: